# - Find OpenICC
# Find the native OpenICC headers and libraries.
#
#  OPENICC_FOUND        - True if OpenICC found.
#  OPENICC_INCLUDE_DIRS - where to find kdb.h, etc.
#  OPENICC_LIBRARIES    - List of libraries when using OpenICC.
#
#  OPENICC_VERSION       - The version of openicc (x.y.z)
#  OPENICC_VERSION_MAJOR - The major version of openicc (x)
#  OPENICC_VERSION_MINOR - The minor version of openicc (y)
#  OPENICC_VERSION_MICRO - The patch version of openicc (z)
#



# Set path to the header file.
FIND_PATH(OPENICC_INCLUDE_DIR
	NAMES openicc_version.h
	PATHS /usr/local/include/openicc
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(OPENICC_INCLUDE_DIR)


# Set path to the library.
FIND_LIBRARY(OPENICC_LIBRARY
	NAMES OpenICC openicc-static
	PATHS /usr/local/lib
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(OPENICC_LIBRARY)

# handle the QUIETLY and REQUIRED arguments and set OPENICC_FOUND to TRUE if
# all listed variables are TRUE
INCLUDE(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(OpenICC DEFAULT_MSG OPENICC_LIBRARY OPENICC_INCLUDE_DIR)

if (OPENICC_FOUND)
        SET( OPENICC_VERSION_MAJOR 0 )
        SET( OPENICC_VERSION_MINOR 1 )
        SET( OPENICC_VERSION_MICRO 0 )
        SET( OPENICC_VERSION 0.1.0 )
        SET( OPENICC_CMMSUBPATH color/modules )
        SET( HAVE_OPENICC TRUE )
	SET(OPENICC_INCLUDE_DIRS ${OPENICC_INCLUDE_DIR})
	SET(OPENICC_LIBRARIES    ${OPENICC_LIBRARY} )
endif (OPENICC_FOUND)
